@@ -121,7 +121,7 @@ class DiscreteEnv(gym.Env):
       list1.append([Prob1])
 
     list_new = pd.DataFrame(list1, columns=['Prob1']) 
-    Ynew_cumul = np.mean(list_new["Prob1"])
+    self.Ynew_cumul = np.mean(list_new["Prob1"])
     #reduce the horizon
     self.horizon -= 1
     
